Struct Daemon

pub struct Daemon<P>
where P: Program,
{ /* private fields */ }
The underlying definition and configuration of an iced daemon.

You can use this API to create and run iced applications step by step—without coupling your logic to a trait or a specific type.

You can create a Daemon with the daemon helper.

Implementations



impl<P> Daemon<P>
where P: Program,

pub fn run(self) -> Result<(), Error>
where Daemon<P>: 'static, <P as Program>::Message: MaybeDebug + MaybeClone,

Runs the Daemon.

pub fn settings(self, settings: Settings) -> Daemon<P>

Sets the Settings that will be used to run the Daemon.

pub fn antialiasing(self, antialiasing: bool) -> Daemon<P>

Sets the Settings::antialiasing of the Daemon.

pub fn default_font(self, default_font: Font) -> Daemon<P>

Sets the default Font of the Daemon.

pub fn font(self, font: impl Into<Cow<'static, [u8]>>) -> Daemon<P>

Adds a font to the list of fonts that will be loaded at the start of the Daemon.

pub fn title( self, title: impl TitleFn<<P as Program>::State>, ) -> Daemon<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>

Sets the title of the Daemon.

pub fn subscription( self, f: impl Fn(&<P as Program>::State) -> Subscription<<P as Program>::Message>, ) -> Daemon<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>

Sets the subscription logic of the Daemon.

pub fn theme( self, f: impl ThemeFn<<P as Program>::State, <P as Program>::Theme>, ) -> Daemon<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>

Sets the theme logic of the Daemon.

pub fn style( self, f: impl Fn(&<P as Program>::State, &<P as Program>::Theme) -> Style, ) -> Daemon<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>

Sets the style logic of the Daemon.

pub fn scale_factor( self, f: impl Fn(&<P as Program>::State, Id) -> f64, ) -> Daemon<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>

Sets the scale factor of the Daemon.

pub fn executor<E>( self, ) -> Daemon<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
where E: Executor,

Sets the executor of the Daemon.

pub fn presets( self, presets: impl IntoIterator<Item = Preset<<P as Program>::State, <P as Program>::Message>>, ) -> Daemon<P>

Sets the boot presets of the Daemon.

Presets can be used to override the default booting strategy of your application during testing to create reproducible environments.